<?php

// This theme supports a variety of post formats.

add_theme_support( 'post-formats', array( 'aside', 'image', 'link', 'quote', 'status' ) );

// Enable thumbnails
add_theme_support('post-thumbnails');
set_post_thumbnail_size( 900, 300, true );// Normal post thumbnails

/*
	 * Adds JavaScript to pages with the comment form to support
	 * sites with threaded comments (when in use).
	 */

if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

function legacy_comments($file) {

	if(!function_exists('wp_list_comments')) : // WP 2.7-only check
		$file = get_template_directory() . '/legacy.comments.php';
	endif;

	return $file;
}
if ( ! function_exists( 'ractopress_comment' ) ) :

function ractopress_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case '' :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<div id="comment-<?php comment_ID(); ?>">
		<div class="comment-author vcard">
			<?php echo get_avatar( $comment, 40 ); ?>
			<?php printf( __( '%s <span class="says">says:</span>', 'ractopress' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>
		</div><!-- .comment-author .vcard -->
		<?php if ( $comment->comment_approved == '0' ) : ?>
			<em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'ractopress' ); ?></em>
			<br />
		<?php endif; ?>

		<div class="comment-meta commentmetadata"><a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
			<?php
				/* translators: 1: date, 2: time */
				printf( __( '%1$s at %2$s', 'ractopress' ), get_comment_date(),  get_comment_time() ); ?></a><?php edit_comment_link( __( '(Edit)', 'ractors' ), ' ' );
			?>
		</div><!-- .comment-meta .commentmetadata -->

		<div class="comment-body"><?php comment_text(); ?></div>

		<div class="reply">
			<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
		</div><!-- .reply -->
	</div><!-- #comment-##  -->

	<?php
			break;
		case 'pingback'  :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'ractopress' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( '(Edit)', 'ractors' ), ' ' ); ?></p>
	<?php
			break;
	endswitch;
}
endif;

// Set a maximum width for Oembedded objects
if ( ! isset( $content_width ) ) $content_width = 900;

/**
 * Registers our main widget area and the front page widget areas.
 */
if ( function_exists('register_sidebar') )
register_sidebar(array('name'=>'Sidebar',
'before_widget' => '',
'after_widget' => '',
'before_title' => '<h3>',
'after_title' => '</h3>',
));

// This theme uses wp_nav_menu() in one location.
	register_nav_menu( 'primary', __( 'Primary Menu', 'ractopress' ) );



// Set a maximum width for Oembedded objects

// Randomly chosen placeholder text for post/page edit screen
function wpfme_writing_encouragement( $content ) {
	global $post_type;
	if($post_type == "post"){
	$encArray = array(
		// Placeholders for the posts editor
		"Test post message one.",
		"Test post message two.",
		"<h1>Test post heading!</h1>"
		);
		return $encArray[array_rand($encArray)];
	}
	else{ $encArray = array(
		// Placeholders for the pages editor
		"Test page message one.",
		"Test page message two.",
		"<h1>Test Page Heading</h1>"
		);
		return $encArray[array_rand($encArray)];
	}
}
add_filter( 'default_content', 'wpfme_writing_encouragement' );


//change amount of posts on the search page - set here to 100
function ractopress_search_results_per_page( $query ) {
	global $wp_the_query;
	if ( ( ! is_admin() ) && ( $query === $wp_the_query ) && ( $query->is_search() ) ) {
	$query->set( 'ractopress_search_results_per_page', 100 );
	}
	return $query;
}
add_action( 'pre_get_posts',  'ractopress_search_results_per_page'  );


//create a permalink after the excerpt
function ractopress_replace_excerpt($content) {
	return str_replace('[...]',
		'<a class="readmore" href="'. get_permalink() .'">Continue Reading</a>',
		$content
	);
}
add_filter('the_excerpt', 'ractopress_replace_excerpt');


// Create custom sizes
// This is then pulled through to your theme useing the_post_thumbnail('custombig');
if ( function_exists( 'add_image_size' ) ) {
	add_image_size('customsmall', 300, 200, true); //narrow column
	add_image_size('custombig', 400, 500, true); //wide column
}

// Add default posts and comments RSS feed links to head
add_theme_support( 'automatic-feed-links' );


// Stop images getting wrapped up in p tags when they get dumped out with the_content() for easier theme styling
function ractopress_remove_img_ptags($content){
	return preg_replace('/<p>\s*(<a .*>)?\s*(<img .* \/>)\s*(\/a>)?\s*<\/p>/iU', '\1\2\3', $content);
}
add_filter('the_content', 'ractopress_remove_img_ptags');
function easy_excerpt_length( $length ) {
	global $EasyExcerptLength;
	if ($EasyExcerptLength) {
    return $EasyExcerptLength;
	} else {
    return 50; //default value
    } }
	add_filter( 'excerpt_length', 'easy_excerpt_length', 999 );
	
	function easy_excerpt_more($more) {
       global $post;
	return '<a href="'. get_permalink($post->ID) . '" class="read-more">Read More</a>';
	}
	add_filter('excerpt_more', 'easy_excerpt_more');
// remove gallery shortcode styling
add_filter('gallery_style',
    create_function(
        '$css',
        'return preg_replace("#<style type=\'text/css\'>(.*?)</style>#s", "", $css);'
    )
);
        
?>